Bohrium
=======
Automatic acceleration of array operations in Python/NumPy, C, and C++ targeting multi-core CPUs and GP-GPUs.

.. image:: https://travis-ci.org/bh107/bohrium.svg?branch=master
    :target: https://travis-ci.org/bh107/bohrium

.. image:: https://badges.gitter.im/bh107/gitter.png
    :target: https://gitter.im/bh107/Lobby

.. image:: https://readthedocs.org/projects/bohrium/badge/?version=latest
    :target: http://bohrium.readthedocs.io/?badge=latest


The documentation is available at `www.bh107.org <http://bohrium.readthedocs.io>`_.
